@@ -50,6 +50,7 @@
 #include <sys/file.h>
 #include <sys/socket.h>
 #include <sys/un.h>
+#include <netinet/in.h>
 #include <rpc/rpc.h>
 #include <rpc/rpc_com.h>
 #ifdef PORTMAP
@@ -77,6 +78,7 @@
 static inline void __nss_configure_lookup(const char *db, const char *s) {}
 #endif
 #include "rpcbind.h"
+#include "xlog.h"
 
 /*#define RPCBIND_DEBUG*/
 
@@ -115,6 +117,9 @@ int nhosts = 0;
 int on = 1;
 int rpcbindlockfd;
 
+#ifdef LIB_SET_DEBUG
+void  libtirpc_set_debug(char *name, int level, int use_stderr);
+#endif
 #ifdef WARMSTART
 /* Local Variable */
 static int warmstart = 0;	/* Grab an old copy of registrations. */
@@ -164,7 +169,7 @@ main(int argc, char *argv[])
 			rl.rlim_cur = 128;
 		setrlimit(RLIMIT_NOFILE, &rl);
 	}
-	openlog("rpcbind", LOG_CONS, LOG_DAEMON);
+
 	if (geteuid()) { /* This command allowed only to root */
 		fprintf(stderr, "Sorry. You are not superuser\n");
 		exit(1);
@@ -189,7 +194,20 @@ main(int argc, char *argv[])
 		syslog(LOG_ERR, "%s: can't find local transport\n", argv[0]);
 		exit(1);
 	}
-	
+	xlog_open("rpcbind");
+	if (dofork) {
+		xlog_syslog(TRUE);
+		xlog_stderr(FALSE);
+	} else {
+		xlog_syslog(FALSE);
+		xlog_stderr(TRUE);
+	}
+	if (debugging) {
+		xlog_config(D_ALL, 1);
+#ifdef LIB_SET_DEBUG
+		libtirpc_set_debug("rpcbind", debugging, (dofork == 0));
+#endif
+	}
 	rpc_control(RPC_SVC_CONNMAXREC_SET, &maxrec);
 
 	init_transport(nconf);
@@ -218,18 +236,16 @@ main(int argc, char *argv[])
 	(void) signal(SIGUSR1, SIG_IGN);
 	(void) signal(SIGUSR2, SIG_IGN);
 
-	if (debugging) {
 #ifdef RPCBIND_DEBUG 
-		printf("rpcbind debugging enabled.");
-		if (doabort) {
-			printf("  Will abort on errors!\n");
-		} else {
-			printf("\n");
-		}
+	if (debugging) {
+		xlog(LOG_DEBUG, "debugging enabled.");
+		if (doabort)
+			xlog(LOG_DEBUG, "Will abort on errors!\n");
+	}
 #endif
-	} else if (dofork) {
+	if (dofork) {
 		if (daemon(0, 0))
-        		err(1, "fork failed");
+        	err(1, "fork failed");
 	}
 
 	if (runasdaemon || rpcbinduser) {
@@ -268,6 +284,13 @@ main(int argc, char *argv[])
 
 	network_init();
 
+#ifdef SYSTEMD
+	/* Try to notify system of successful startup, regardless of whether we
+	 * used systemd socket activation or not. When started from the command
+	 * line, this should not hurt either.
+	 */
+	sd_notify(0, "READY=1");
+#endif
 	my_svc_run();
 	syslog(LOG_ERR, "svc_run returned unexpectedly");
 	rpcbind_abort();
@@ -276,6 +299,31 @@ main(int argc, char *argv[])
 	return 0;
 }
 
+/*
+ * Normally systemd will open sockets in dual ipv4/ipv6 mode.
+ * That won't work with netconfig and we'll only match
+ * the ipv6 socket. Convert it to IPV6_V6ONLY and issue
+ * a warning for the user to fix their systemd config.
+ */
+static int
+handle_ipv6_socket(int fd)
+{
+	int opt;
+	socklen_t len = sizeof(opt);
+
+	if (getsockopt(fd, IPPROTO_IPV6, IPV6_V6ONLY, &opt, &len)) {
+		syslog(LOG_ERR, "failed to get ipv6 socket opts: %m");
+		return -1;
+	}
+
+	if (opt) /* socket is already in V6ONLY mode */
+		return 0;
+
+	syslog(LOG_ERR, "systemd has passed an IPv4/IPv6 dual-mode socket.");
+	syslog(LOG_ERR, "Please fix your systemd config by specifying IPv4 and IPv6 sockets separately and using BindIPv6Only=ipv6-only.");
+	return -1;
+}
+
 /*
  * Adds the entry into the rpcbind database.
  * If PORTMAP, then for UDP and TCP, it adds the entries for version 2 also
@@ -311,11 +359,11 @@ init_transport(struct netconfig *nconf)
 		int i;
 		char **s;
 
-		(void) fprintf(stderr, "%s: %ld lookup routines :\n",
+		(void) xlog(LOG_DEBUG, "%s: %ld lookup routines :\n",
 			nconf->nc_netid, nconf->nc_nlookups);
 		for (i = 0, s = nconf->nc_lookups; i < nconf->nc_nlookups;
 		     i++, s++)
-			fprintf(stderr, "[%d] - %s\n", i, *s);
+			xlog(LOG_DEBUG, "[%d] - %s\n", i, *s);
 	}
 #endif
 	if (!__rpc_nconf2sockinfo(nconf, &si)) {
@@ -361,6 +409,9 @@ init_transport(struct netconfig *nconf)
 			goto error;
 		}
 
+		if (sa.sa.sa_family == AF_INET6 && handle_ipv6_socket(fd))
+		        goto error;
+
 		/* Copy the address */
 		taddr.addr.maxlen = taddr.addr.len = addrlen;
 		taddr.addr.buf = malloc(addrlen);
@@ -389,18 +440,6 @@ init_transport(struct netconfig *nconf)
 	if (my_xprt != NULL)
 		goto got_socket;
 
-	/*
-	 * XXX - using RPC library internal functions. For NC_TPI_CLTS
-	 * we call this later, for each socket we like to bind.
-	 */
-	if (nconf->nc_semantics != NC_TPI_CLTS) {
-		if ((fd = __rpc_nconf2fd(nconf)) < 0) {
-			syslog(LOG_ERR, "cannot create socket for %s",
-			    nconf->nc_netid);
-			return (1);
-		}
-	}
-
 	if ((strcmp(nconf->nc_netid, "local") == 0) ||
 	    (strcmp(nconf->nc_netid, "unix") == 0)) {
 		memset(&sun, 0, sizeof sun);
@@ -451,11 +490,13 @@ init_transport(struct netconfig *nconf)
 				    nconf->nc_netid);
 				return (1);
 			}
+
+			hints.ai_flags &= ~AI_NUMERICHOST;
 			switch (hints.ai_family) {
 			case AF_INET:
 				if (inet_pton(AF_INET, hosts[nhostsbak],
 				    host_addr) == 1) {
-					hints.ai_flags &= AI_NUMERICHOST;
+					hints.ai_flags |= AI_NUMERICHOST;
 				} else {
 					/*
 					 * Skip if we have an AF_INET6 adress.
@@ -468,7 +509,7 @@ init_transport(struct netconfig *nconf)
 			case AF_INET6:
 				if (inet_pton(AF_INET6, hosts[nhostsbak],
 				    host_addr) == 1) {
-					hints.ai_flags &= AI_NUMERICHOST;
+					hints.ai_flags |= AI_NUMERICHOST;
 				} else {
 					/*
 					 * Skip if we have an AF_INET adress.
@@ -545,7 +586,7 @@ init_transport(struct netconfig *nconf)
 				}
 				nb.len = nb.maxlen = sa_size;
 				uaddr = taddr2uaddr(nconf, &nb);
-				(void) fprintf(stderr,
+				(void) xlog(LOG_DEBUG,
 				    "rpcbind : my address is %s\n", uaddr);
 				(void) free(uaddr);
 			}
@@ -561,6 +602,12 @@ init_transport(struct netconfig *nconf)
 		if (!checkbind)
 			return 1;
 	} else {	/* NC_TPI_COTS */
+		if ((fd = __rpc_nconf2fd(nconf)) < 0) {
+			syslog(LOG_ERR, "cannot create socket for %s",
+			    nconf->nc_netid);
+			return (1);
+		}
+
 		if ((strcmp(nconf->nc_netid, "local") != 0) &&
 		    (strcmp(nconf->nc_netid, "unix") != 0)) {
 			if ((aicode = getaddrinfo(NULL, servname, &hints, &res))!= 0) {
@@ -622,7 +669,7 @@ init_transport(struct netconfig *nconf)
 			}
 			nb.len = nb.maxlen = sa_size2;
 			uaddr = taddr2uaddr(nconf, &nb);
-			(void) fprintf(stderr, "rpcbind : my address is %s\n",
+			(void) xlog(LOG_DEBUG, "rpcbind : my address is %s\n",
 			    uaddr);
 			(void) free(uaddr);
 		}
@@ -729,13 +776,13 @@ got_socket:
 #ifdef RPCBIND_DEBUG
 	if (debugging) {
 		if (status < 0) {
-			fprintf(stderr, "Error in finding bind status for %s\n",
+			xlog(LOG_DEBUG, "Error in finding bind status for %s\n",
 				nconf->nc_netid);
 		} else if (status == 0) {
-			fprintf(stderr, "check binding for %s\n",
+			xlog(LOG_DEBUG, "check binding for %s\n",
 				nconf->nc_netid);
 		} else if (status > 0) {
-			fprintf(stderr, "No check binding for %s\n",
+			xlog(LOG_DEBUG, "No check binding for %s\n",
 				nconf->nc_netid);
 		}
 	}
@@ -749,11 +796,11 @@ got_socket:
 #ifdef RPCBIND_DEBUG
 		if (debugging) {
 			if (status < 0) {
-				fprintf(stderr,
+				xlog(LOG_DEBUG,
 				    "Could not create rmtcall fd for %s\n",
 					nconf->nc_netid);
 			} else {
-				fprintf(stderr, "rmtcall fd for %s is %d\n",
+				xlog(LOG_DEBUG, "rmtcall fd for %s is %d\n",
 					nconf->nc_netid, status);
 			}
 		}
@@ -778,8 +825,8 @@ rbllist_add(rpcprog_t prog, rpcvers_t vers, struct netconfig *nconf,
 	}
 #ifdef RPCBIND_DEBUG	
 	if (debugging){
-	  fprintf(stderr,"FUNCTION rbllist_add");
-	  fprintf(stderr,"Add the prog %lu vers %lu to the rpcbind list\n",
+	  xlog(LOG_DEBUG,"FUNCTION rbllist_add");
+	  xlog(LOG_DEBUG,"Add the prog %lu vers %lu to the rpcbind list",
                   (ulong)prog, (ulong)vers);
 	}
 #endif	
@@ -829,7 +876,7 @@ parseargs(int argc, char *argv[])
 			break;		/* errors; for rpcbind developers */
 					/* only! */
 		case 'd':
-			debugging = 1;
+			debugging++;
 			break;
 		case 'h':
 			++nhosts;
